timeseries.SpaceCurve.copy — GDA Toolbox v1.0 Manual

- GDA Toolbox v1.0 Manual
- Time-Series Data
- timeseries.SpaceCurve

- index
- modules
- next
- previous

# timeseries.SpaceCurve.copy

`SpaceCurve.` `copy`()

  make an identical copy of self.

#### Previous topic

timeseries.SpaceCurve.compute

#### Next topic

timeseries.SpaceCurve.duration

- © Copyright 2015-2017, Geometric Data Analytics, Inc.
- Last updated on Jan 07, 2019.
- Created using Sphinx 1.8.2.